==> geant4.9.6.p02.tar.gz: geant4.9.6.p02/examples/.doxygen/Doxymodules_optical.h <==
// $Id: Doxymodules_optical.h 60059 2012-06-27 13:00:49Z gcosmo $
// The example class categories definitions for Doxygen

/// \file Doxymodules_optical.h
/// \brief The page that defines the extended/optical examples modules 


/** @defgroup extended_optical optical
 *  Extended optical examples classes
 *  @{
 */

/** @defgroup extended_optical_LXe LXe
 *  Optical example LXe 
 *  @ingroup extended_optical
 *  @{
 */

  class LXeDetectorConstruction {};
  class LXeDetectorMessenger {};
  class LXeEMPhysics {};
  class LXeEventAction {};
  class LXeEventMessenger {};
  class LXeGeneralPhysics {};
  class LXeMainVolume {};
  class LXeMuonPhysics {};
  class LXePhysicsList {};
  class LXePMTHit {};
  class LXePMTSD {};
  class LXePrimaryGeneratorAction {};
  class LXeRunAction {};
  class LXeScintHit {};
  class LXeScintSD {};
  class LXeStackingAction {};
  class LXeSteppingAction {};
  class LXeSteppingMessenger {};
  class LXeSteppingVerbose {};
  class LXeTrackingAction {};
  class LXeTrajectory {};
  class LXeUserEventInformation {};
  class LXeUserTrackInformation {};
  class LXeWLSFiber {};
  class LXeWLSSlab {};
  class RecorderBase {};

/** @} */

/** @defgroup extended_optical_wls wls
 *  Optical example wls 
 *  @ingroup extended_optical
 *  @{
 */

  class WLSDetectorConstruction {};
  class WLSDetectorMessenger {};
  class WLSEventAction {};
  class WLSEventActionMessenger {};
  class WLSExtraPhysics {};
  class WLSMaterials {};
  class WLSOpticalPhysics {};
  class WLSPhotonDetHit {};
  class WLSPhotonDetSD {};
  class WLSPhysicsList {};
  class WLSPhysicsListMessenger {};
  class WLSPrimaryGeneratorAction {};
  class WLSPrimaryGeneratorMessenger {};
  class WLSRunAction {};
  class WLSRunActionMessenger {};
  class WLSStackingAction {};
  class WLSStepMax {};
  class WLSSteppingAction {};
  class WLSSteppingActionMessenger {};
  class WLSSteppingVerbose {};
  class WLSTrackingAction {};
  class WLSTrajectory {};
  class WLSTrajectoryPoint {};
  class WLSUserTrackInformation {};

/** @} */

/** @} */

==> geant4.10.04.p03.tar.gz: geant4.10.04.p03/examples/.doxygen/Doxymodules_optical.h <==
// $Id$
// The example class categories definitions for Doxygen

/// \file Doxymodules_optical.h
/// \brief The page that defines the extended/optical examples modules 


/** @defgroup extended_optical optical
 *  Extended optical examples classes
 *  @{
 */

/** @defgroup extended_optical_OpNovice OpNovice
 *  Optical example OpNovice
 *  @ingroup extended_optical
 *  @{
 */
 
  class OpNoviceActionInitialization {};
  class OpNoviceDetectorConstruction {};
  class OpNovicePhysicsList {};
  class OpNovicePhysicsListMessenger {};
  class OpNovicePrimaryGeneratorAction {};
  class OpNovicePrimaryGeneratorMessenger {};
  class OpNoviceRunAction {};
  class OpNoviceStackingAction {};
  class OpNoviceSteppingAction {};
  class OpNoviceSteppingVerbose {}; 

/** @} */


/** @defgroup extended_optical_LXe LXe
 *  Optical example LXe 
 *  @ingroup extended_optical
 *  @{
 */

  class LXeActionInitialization {};
  class LXeDetectorConstruction {};
  class LXeDetectorMessenger {};
  class LXeEMPhysics {};
  class LXeEventAction {};
  class LXeEventMessenger {};
  class LXeGeneralPhysics {};
  class LXeMainVolume {};
  class LXeMuonPhysics {};
  class LXePMTHit {};
  class LXePMTSD {};
  class LXePhysicsList {};
  class LXePrimaryGeneratorAction {};
  class LXeRecorderBase {};
  class LXeRunAction {};
  class LXeScintHit {};
  class LXeScintSD {};
  class LXeStackingAction {};
  class LXeSteppingAction {};
  class LXeSteppingMessenger {};
  class LXeSteppingVerbose {};
  class LXeTrackingAction {};
  class LXeTrajectory {};
  class LXeUserEventInformation {};
  class LXeUserTrackInformation {};
  class LXeWLSFiber {};
  class LXeWLSSlab {};
  class RecorderBase {};

/** @} */

/** @defgroup extended_optical_wls wls
 *  Optical example wls 
 *  @ingroup extended_optical
 *  @{
 */

  class WLSActionInitialization {};
  class WLSDetectorConstruction {};
  class WLSDetectorMessenger {};
  class WLSEventAction {};
  class WLSEventActionMessenger {};
  class WLSExtraPhysics {};
  class WLSMaterials {};
  class WLSOpticalPhysics {};
  class WLSPhotonDetHit {};
  class WLSPhotonDetSD {};
  class WLSPhysicsList {};
  class WLSPhysicsListMessenger {};
  class WLSPrimaryGeneratorAction {};
  class WLSPrimaryGeneratorMessenger {};
  class WLSRunAction {};
  class WLSRunActionMessenger {};
  class WLSStackingAction {};
  class WLSStepMax {};
  class WLSSteppingAction {};
  class WLSSteppingActionMessenger {};
  class WLSSteppingVerbose {};
  class WLSTrackingAction {};
  class WLSTrajectory {};
  class WLSTrajectoryPoint {};
  class WLSUserTrackInformation {};

/** @} */

/** @} */
